GRPC.Client.LoadBalancing behaviour (gRPC v0.11.5)
View SourceLoad balancing behaviour for gRPC clients.
This module defines the behaviour that load balancing strategies must implement.
Load balancing behaviour for gRPC clients.
This module defines the behaviour that load balancing strategies must implement.