GRPC.Logger (gRPC v0.11.5)

Summary

Functions

Normalizes the exception and stacktrace inputs by its kind to match the format specified for crash_report metadata in Logger

Functions

crash_reason(atom, reason, stacktrace)

Normalizes the exception and stacktrace inputs by its kind to match the format specified for crash_report metadata in Logger