GRPC.Logger (gRPC v0.11.5)
View SourceSummary
Functions
Normalizes the exception and stacktrace inputs by its kind to match the format specified for crash_report metadata
in Logger
Normalizes the exception and stacktrace inputs by its kind to match the format specified for crash_report metadata
in Logger